package com.lenovo.lasf.speech.view;

import android.content.Context;
import android.content.res.Resources;
import android.graphics.Canvas;
import android.graphics.Rect;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;

public class BaseDrawable extends BitmapDrawable{
    private Drawable mRotatingDrawable;
    private PingDrawable mPingDrawable;
    private BreatheDrawable mBreatheDrawable;
    private ScaleDrawable mScaleDrawable;
    private ScaleAnimDrawable mScaleAnimDrawable;
    private BigCircleDrawable mBigCircleDrawable;
    public BaseDrawable(Context context,Resources res) {
        mScaleDrawable = new ScaleDrawable(context, res);
        mScaleAnimDrawable = new ScaleAnimDrawable(context, res);
        mRotatingDrawable = new RotatingDrawable(context, res);
        mPingDrawable = new PingDrawable(context, res);
        mBreatheDrawable = new BreatheDrawable(context, res);
        mBigCircleDrawable = new BigCircleDrawable(context, res);
    }
    @Override
    protected void onBoundsChange(Rect bounds) {
        super.onBoundsChange(bounds);
        mRotatingDrawable.setBounds(bounds);
        mPingDrawable.setBounds(bounds);
        mBreatheDrawable.setBounds(bounds);
        mScaleDrawable.setBounds(bounds);
        mScaleAnimDrawable.setBounds(bounds);
        mBigCircleDrawable.setBounds(bounds);
    }
    
    @Override
    public void draw(Canvas canvas) {
        super.draw(canvas);
        if (mShowV1) {
            mScaleAnimDrawable.draw(canvas);
            mScaleDrawable.draw(canvas);
            mPingDrawable.draw(canvas);
            mBreatheDrawable.draw(canvas);
            mBigCircleDrawable.draw(canvas);
        }
        
        if (mShowV2) {
            mRotatingDrawable.draw(canvas);
        }
        
    }
    boolean mShowV1 = false;
    boolean mShowV2 = false;
    
    public void showV1() {
        clearOthers();
        mShowV1 = true;
    }
    public void showBigCircle() {
        mBigCircleDrawable.showBigCircle();
    }
    public void showV2() {
        clearOthers();
        mShowV2 = true;
    }
    private void clearOthers() {
        mShowV1 = false;
        mShowV2 = false;
    }
    public void setScaleSize(float scale) {
        mScaleDrawable.setScaleXY(scale);
    }
    public void ping() {
        mPingDrawable.ping();
    }
    public void startBreatheAnim() {
        mBreatheDrawable.startBreathe();
    }
    public void stopBreatheAnim() {
        mBreatheDrawable.stopBreathe();
    }
    public void postScaleAnim() {
        mScaleAnimDrawable.postScaleAnim();
    }
}
