package com.lenovo.lasf.speech.view;

import android.content.Context;
import android.content.res.Resources;
import android.graphics.Canvas;
import android.graphics.Matrix;
import android.graphics.Rect;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.view.animation.Animation;
import android.view.animation.AnimationUtils;
import android.view.animation.LinearInterpolator;
import android.view.animation.RotateAnimation;
import android.view.animation.Transformation;

import com.lenovo.lasf_lite.R;

public class RotatingDrawable extends BitmapDrawable{
    private Drawable mRotating;
    private Drawable mMic;
    private RotateAnimation mRotateAnimation;
    public RotatingDrawable(Context context,Resources res) {
        mRotating = (BitmapDrawable) res.getDrawable(R.drawable.lasf_lite_center_halo_rotate);
        mMic = (BitmapDrawable) res.getDrawable(R.drawable.lasf_lite_center_recognizing_mic);
    }
    
    @Override
    protected void onBoundsChange(Rect bounds) {
        super.onBoundsChange(bounds);
        int pWidth = bounds.width();
        int pHeight = bounds.height();
        
        int minimumHeight = mRotating.getMinimumHeight();
        int minimumWidth = mRotating.getMinimumWidth();
        
        mRotating.setBounds((pWidth - minimumWidth) / 2 ,(pHeight - minimumHeight) / 2 ,(pWidth + minimumWidth) / 2,(pHeight + minimumHeight) / 2);
        minimumHeight = mMic.getMinimumHeight();
        minimumWidth = mMic.getMinimumWidth();
        
        mMic.setBounds((pWidth - minimumWidth) / 2 ,(pHeight - minimumHeight) / 2 ,(pWidth + minimumWidth) / 2,(pHeight + minimumHeight) / 2);
        
        mRotateAnimation = new RotateAnimation(0f,360f,RotateAnimation.RELATIVE_TO_SELF,0.5f,RotateAnimation.RELATIVE_TO_SELF,0.5f) {
        };
        mRotateAnimation.initialize(pWidth, pHeight, pWidth, pHeight);
        mRotateAnimation.setInterpolator(new LinearInterpolator());
        mRotateAnimation.setDuration(800);
        mRotateAnimation.setRepeatCount(Animation.INFINITE);
        mRotateAnimation.startNow();
    }
    
    @Override
    public void draw(Canvas canvas) {
        super.draw(canvas);
        canvas.save();
        canvas.clipRect(getBounds());
        Transformation tf = new Transformation();
        mRotateAnimation.getTransformation(AnimationUtils.currentAnimationTimeMillis(), tf);
        Matrix matrix = tf.getMatrix();
        canvas.save();
        mMic.draw(canvas);
        canvas.restore();
        canvas.concat(matrix);
        mRotating.draw(canvas);
        canvas.restore();
    }
}
