package com.lenovo.lasf.speech.view;

import android.content.Context;
import android.os.Bundle;
import android.os.Handler;
import android.os.HandlerThread;
import android.speech.RecognitionListener;
import android.util.Log;
import android.view.View;
import android.view.animation.AccelerateInterpolator;
import android.widget.Button;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.lenovo.lasf.speech.LasfMainActivity;
import com.lenovo.lasf_lite.R;

public class ScSpeechView extends RelativeLayout implements RecognitionListener ,View.OnClickListener{
    Context mContext;
    protected static final int WHAT_START_POINT_ANIM = 0;
    protected static final float MAX_LEVEL = (float) (Short.MAX_VALUE * 0.2);
    private RelativeLayout mContainerLayout;
    private RelativeLayout mBottomRecordingLayout;
    private RelativeLayout mBottomRecognizingLayout;
    private Button mBottomRecognizingBtnCancle;
    private RelativeLayout mAnimationViewLayout;
    private TextView mCenterViewMask;
    public ScSpeechView(Context context) {
        super(context);
        mContext = context;
        inflate(context, R.layout.sc_speech_view, this);
        
        mContainerLayout = (RelativeLayout) findViewById(R.id.lasf_lite_bg);
        mAnimationViewLayout = (RelativeLayout) findViewById(R.id.lasf_lite_center_anim_view);
        mCenterViewMask = (TextView) findViewById(R.id.lasf_lite_center_mask);
        
        mBottomRecordingLayout = (RelativeLayout) findViewById(R.id.lasf_lite_bottom_two_element_layout);
        mBottomRecognizingLayout = (RelativeLayout) findViewById(R.id.lasf_lite_bottom_one_element_layout);
        mBottomRecordingBtnStop = (Button) findViewById(R.id.lasf_lite_bottom_left);
        mBottomRecordingBtnCancle = (Button) findViewById(R.id.lasf_lite_bottom_right);
        mBottomRecognizingBtnCancle = (Button) findViewById(R.id.lasf_lite_bottom_btncancle);
        bindEvent();
        invalidate();
    }
    


    private void bindEvent() {
        mBottomRecordingBtnStop.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (null != mOnBtnClickListener) {
                    mOnBtnClickListener.onBtnStopClick();
                  //AnalyticsTracker.getInstance().trackEvent("ScSpeechView","recording_stop_btnclicked",null,0);
                }
            }
        });
        mBottomRecordingBtnCancle.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                hide();
                if (null != mOnBtnClickListener) {
                    mOnBtnClickListener.onBtnCancelClick();
                }
            }
        });
        mBottomRecognizingBtnCancle.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                hide();
                if (null != mOnBtnClickListener) {
                    mOnBtnClickListener.onBtnCancelClick();
                }
            }
        });
    }

    @Override
    public void onReadyForSpeech(Bundle params) {
    }
    @Override
    public void onBeginningOfSpeech() {
        mAnimationView.showBigCircle();
        notYetSpeech = false;
        mAnimationView.stopBreatheAnim();
    }
    private float lastRms;
    private float minRms = 1000;
    private float maxRms;
    
    boolean notYetSpeech = true;
    @Override
    public void onRmsChanged(float rmsdB) {
        Log.e("yyy", "onRmsChanged");
        if (notYetSpeech) {
            return;
        }
        minRms = Math.min(minRms,rmsdB);
        maxRms = Math.max(maxRms,rmsdB);
        up(rmsdB,lastRms,maxRms);
        float avg = (minRms + maxRms) / 2;
        if (rmsdB != 0) {
            if (rmsdB  > avg) {
                mAnimationView.ping();
            }else{
//                down(rmsdB,lastRms,maxRms);
            }
        }
        lastRms = rmsdB;
    }
    private void up(float rmsdB2, float lastRms2, float maxRms2) {
        maxRms2 = maxRms2 > MAX_LEVEL ? MAX_LEVEL : maxRms2;
        rmsdB2 = rmsdB2 > maxRms2 ? maxRms2 : rmsdB2;
        lastRms2 = lastRms2 > maxRms2 ? maxRms2 : lastRms2;
        float gap = rmsdB2 - lastRms2;
        int loopTimes = 5;
        for (int i = 0; i < loopTimes; i++) {
            final float scalValue = (float) ((lastRms2 + gap * i / loopTimes) / maxRms2 * 2.0);
            mRmsHandler.postDelayed(new Runnable() {
                public void run() {
                    mAnimationView.setScaleSize(scalValue < 1 ? 1 : scalValue);
                }
            }, 8 * i);
        }
    }
    @Override
    public void onBufferReceived(byte[] buffer) {
        
    } 
    @Override
    public void onEndOfSpeech() {
        if (!notYetSpeech) {
            showRecognizingLayout();
        }
    }

    @Override
    protected void onVisibilityChanged(View changedView, int visibility) {
        super.onVisibilityChanged(changedView, visibility);
        if (visibility == View.GONE) {
            recycle();
        }else if (visibility == View.VISIBLE) {
            showReal();
            HandlerThread ht = new HandlerThread("rmsThread");
            ht.start();
            mRmsHandler = new Handler(ht.getLooper());
        }
    }
    @Override
    protected void onMeasure(int widthMeasureSpec, int heightMeasureSpec) {
        super.onMeasure(widthMeasureSpec, heightMeasureSpec);
    }
    
    @Override
    public void onError(int error) {
        if (null != mOnResultBackListener) {
            mOnResultBackListener.onErrorBack(error);
        }
    }
    @Override
    public void onResults(Bundle results) {
        if (null != mOnResultBackListener) {
            mOnResultBackListener.onResultBack(results);
        }
    }
    @Override
    public void onPartialResults(Bundle partialResults) {
        
    }
    @Override
    public void onEvent(int eventType, Bundle params) {
        
    }
    @Override
    public void onClick(View v) {
        if (null != mOnBtnClickListener) {
            mOnBtnClickListener.onBtnStopClick();
        }
    }
    
    public void recycle() {
        if (mRmsHandler != null) {
            mRmsHandler.getLooper().quit();
        }
        if (mAnimationView != null) {
            mAnimationView.clean();
        }
    }
    OnBtnClickListener mOnBtnClickListener;
    OnResultBackListener mOnResultBackListener;
    private Button mBottomRecordingBtnStop;
    private Button mBottomRecordingBtnCancle;
    
    public void setOnBtnClickListener(OnBtnClickListener listener){
        mOnBtnClickListener = listener;
    }
    public void setOnResultBackListener(OnResultBackListener listener){
        mOnResultBackListener = listener;
    }
    void showRecordingLayout(){
        mContainerLayout.setVisibility(View.VISIBLE);
        mBottomRecordingLayout.setVisibility(View.VISIBLE);
        mBottomRecognizingLayout.setVisibility(View.GONE);
    }
    void showRecognizingLayout(){
        mAnimationView.showView2();
        mAnimationView.setTextTips("识别中");
        mContainerLayout.setVisibility(View.VISIBLE);
        mBottomRecordingLayout.setVisibility(View.GONE);
        mBottomRecognizingLayout.setVisibility(View.VISIBLE);
    }
    
    private void showReal() {
        mAnimationView = new AnimationView(getContext());
        int duration = 0;
        if (mShowAnim) {
            mCenterViewMask.setVisibility(View.VISIBLE);
            duration = 700;
            MyScaleAnimation animation = new MyScaleAnimation(getContext(), null);
            animation.setInterpolator(new AccelerateInterpolator(2f));
            this.setAnimation(animation);
            animation.start();
        }
        postDelayed(new Runnable() {
            @Override
            public void run() {
                notYetSpeech = true;
                showRecordingLayout();
                mAnimationViewLayout.addView(mAnimationView);
                mAnimationView.showView1();
                mAnimationView.setTextTips("录音中");
                mCenterViewMask.setVisibility(View.GONE);
            }
        }, duration);
    }
    boolean mShowAnim = false;
    public void show(boolean showAnim) {
        mShowAnim = showAnim;
    }
    
    private AnimationView mAnimationView;
    
    private long mIxid;
    private Handler mRmsHandler;
    
    public void hide() {
        this.setVisibility(View.GONE);
    }
    
    public long getIxid(){
        return mIxid;
    }

    public void reset() {
        lastRms = 0;
        minRms = 1000;
        maxRms = 0;
        if (mAnimationView != null) {
            mAnimationView.clean();
        }
        show(false);
    }
}
